task arriba{
    String sample_id
    File fastq1
    File fastq2
    File STAR_INDEX_DIR
    File ASSEMBLY_FA
    File ANNOTATION_GTF

    String disk_size
    String docker
    String cluster

    command <<<
	
        set -o pipefail
        set -e

        mkdir ./output/
        STAR \
            --runThreadN 16 \
            --genomeDir ${STAR_INDEX_DIR} \
            --genomeLoad NoSharedMemory \
            --readFilesIn ${fastq1} ${fastq2} \
            --readFilesCommand zcat \
            --outSAMtype BAM SortedByCoordinate \
            --outSAMunmapped Within \
            --outBAMcompression 0 \
            --outFilterMultimapNmax 50 \
            --peOverlapNbasesMin 10 \
            --alignSplicedMateMapLminOverLmate 0.5 \
            --alignSJstitchMismatchNmax 5 -1 5 5 \
            --chimSegmentMin 10 \
            --chimOutType WithinBAM HardClip \
            --chimJunctionOverhangMin 10 \
            --chimScoreDropMax 30 \
            --chimScoreJunctionNonGTAG 0 \
            --chimScoreSeparation 1 \
            --chimSegmentReadGapMax 3 \
            --chimMultimapNmax 50 \
            --outFileNamePrefix ./output/${sample_id}.
                  
                  
         /arriba_v2.1.0/arriba \
            -x ./output/${sample_id}.Aligned.sortedByCoord.out.bam \
            -o ./output/${sample_id}_fusions.tsv -O ./output/${sample_id}_fusions.discarded.tsv \
            -a ${ASSEMBLY_FA} \
            -g ${ANNOTATION_GTF} \
            -b /arriba_v2.1.0/database/blacklist_hg38_GRCh38_v2.1.0.tsv.gz \
            -k /arriba_v2.1.0/database/known_fusions_hg38_GRCh38_v2.1.0.tsv.gz \
            -t /arriba_v2.1.0/database/known_fusions_hg38_GRCh38_v2.1.0.tsv.gz \
            -p /arriba_v2.1.0/database/protein_domains_hg38_GRCh38_v2.1.0.gff3

         samtools index -@ 16 ./output/${sample_id}.Aligned.sortedByCoord.out.bam ./output/${sample_id}.Aligned.sortedByCoord.out.bam.bai
         
         Rscript /arriba_v2.1.0/draw_fusions.R \
            --fusions=./output/${sample_id}_fusions.tsv \
            --alignments=./output/${sample_id}.Aligned.sortedByCoord.out.bam \
            --output=./output/${sample_id}_fusion.pdf \
            --annotation=${ANNOTATION_GTF} \
            --cytobands=/arriba_v2.1.0/database/cytobands_hg38_GRCh38_v2.1.0.tsv \
            --proteinDomains=/arriba_v2.1.0/database/protein_domains_hg38_GRCh38_v2.1.0.gff3


    >>>
	
    runtime {
        docker: docker
        cluster: cluster
        systemDisk: "cloud_ssd 40"
        dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
    }

    output {
        Array[File] arriba_result=glob("./output/*.tsv")
        Array[File] arriba_pdf=glob("./output/*.pdf")
    }

}


